@@ -7,23 +7,26 @@ from os.path import join
 from hashlib import md5
 from pathlib import Path
 import shutil
-import requests
+import aiohttp
+import aiofiles
+from aiohttp.helpers import BasicAuth
 
-def get_from_file(fname,dont_read=False):
+async def get_from_file(fname,dont_read=False):
     """get_from_file method"""
     try:
         if os.path.isfile(fname):
             if dont_read:
                 return {}
             try:
-                with open(fname,encoding='utf8') as file:
-                    return json.load(file)
+                async with aiofiles.open(fname,encoding='utf8') as file:
+                    content = await file.read()
+                return json.loads(content)
             except json.JSONDecodeError:
                 print("Error at TUCache get_from_file(1):\n"+str(traceback.format_exc()))
                 try:
                     os.remove(fname)
                 except OSError:
-                    pass
+                    print("Error at TUCache get_from_file(3):\n"+str(traceback.format_exc()))
                 return None
         else:
             return None
@@ -34,7 +37,7 @@ def get_from_file(fname,dont_read=False):
 class WebCache:
     """WebCache class"""
     def __init__(self,auth=None,_dir=None,verbose=False):
-        self.auth = auth
+        self.auth = BasicAuth(auth[0],auth[1]) if auth is not None else None
         self.verbose = verbose
         if _dir is None:
             self.dir = "web-cache"
@@ -52,28 +55,27 @@ class WebCache:
         except OSError:
             print("Error at TUCache clean:\n"+str(traceback.format_exc()))
         Path(self.dir).mkdir(parents=True, exist_ok=True)
-    def get_from_web(self,url):
+    async def get_from_web(self,url: str) -> dict:
         """get_from_web method"""
-        resp = requests.get(url, auth=self.auth)
-        if resp.status_code != 200:
-            raise Exception(
-                "Could not get data from server (http error) code "+str(resp.status_code))
-        return resp
-    def get(self,url):
+        async with aiohttp.ClientSession() as session:
+            async with session.request('GET', url,auth=self.auth) as response:
+                response.raise_for_status()
+                _j = await response.json()
+                _t = await response.text()
+                return _j , _t
+    async def get(self,url):
         """get method"""
         fname = md5(url.encode('utf-8')).hexdigest()+".json"
         if self.return_only_cache_files:
             return fname
         fname = join(self.dir,fname)
-        data = get_from_file(fname,self.dont_read_files)
+        data = await get_from_file(fname,self.dont_read_files)
         if data is None:
-            resp = self.get_from_web(url)
-            if len(resp.text) > self.min_write_len:
-                with open(fname,'w',encoding='utf8') as file:
-                    file.write(resp.text)
-            data = resp.json()
+            data, text = await self.get_from_web(url)
+            async with aiofiles.open(fname, mode='w+',encoding='utf8') as _fp:
+                await _fp.write(text)
             if self.verbose:
-                print(url,len(str(data)),"W")
+                print(url,len(text),"W")
         else:
             if self.verbose:
                 print(url,len(str(data)),"C")
